@@ -45,8 +45,8 @@ def _parse_args(args=sys.argv[1:]):
     parser.add_argument('-c', '--cmake-only', action='store_true', help='Do not compile, just force a re-run of cmake [false]')
     group = parser.add_mutually_exclusive_group()
     group.add_argument('-i', '--install', action='store_true', help='Run install step after making [false]')
-    group.add_argument('--track', choices=['groovy', 'hydro'], dest='default_underlay', action='store', default=None, help='convenience equivalent for the --default-underlay option')
-    group.add_argument('--install-rosdeps-track', choices=['groovy', 'hydro'], action='store', default=None, help='Install all rosdeps for the workspace sources and given track [None]')
+    group.add_argument('--track', choices=settings.VALID_TRACKS, dest='default_underlay', action='store', default=None, help='convenience equivalent for the --default-underlay option')
+    group.add_argument('--install-rosdeps-track', choices=settings.VALID_TRACKS, action='store', default=None, help='Install all rosdeps for the workspace sources and given track [None]')
     group.add_argument('--install-rosdeps', action='store_true', help='Install all rosdeps for the workspace sources and track set by `yujin_tools_settings --get-default-track` [false]')
     group.add_argument('-t', '--tests', action='store_true', help='Make tests [false]')
     parser.add_argument('--no-color', action='store_true', help='Disables colored ouput')
